package
Version:
v0.0.0-...-889a1ee
Opens a new window with list of versions in this module.
Published: Aug 27, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type NtOpDto struct {
ActionTime *time.Time
}
NtOpDto 非授权操作对象
type OpDto interface {
GetActionTime() *time.Time
}
OpDto 操作对象DTO
Source Files
¶
Click to show internal directories.
Click to hide internal directories.