package
Version:
v0.0.0-...-889a1ee
Opens a new window with list of versions in this module.
Published: Aug 27, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type UploadReqDto struct {
Action string `json:"action"`
FileName string `json:"fileName"`
}
type UploadResDto struct {
FileKey string `json:"fileKey"`
FileUrl string `json:"fileUrl"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.